@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2022 A S Lewis
+# Copyright (C) 2019-2023 A S Lewis
 #
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
 #
 # This program is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 # details.
 #
-# You should have received a copy of the GNU General Public License along with
-# this program. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 
 """Constant variables used in various parts of the code."""
@@ -43,6 +43,7 @@ locale_setup_list = [
     'ko_KR',    '한국어',
     'nl_NL',    'Nederlands',
     'ru',       'русский',
+    'tr',       'Türkçe',
     'vi',       'Tiếng Việt',
 ]
 
@@ -57,10 +58,10 @@ while locale_setup_list:
     LOCALE_LIST.append(key)
     LOCALE_DICT[key] = value
 
-# Some icons are different at Christmas/on national holidays
+# Some icons are different at Christmas and on national holidays
 today = datetime.date.today()
-day = today.strftime("%d")
-month = today.strftime("%m")
+day = today.strftime('%d')
+month = today.strftime('%m')
 
 xmas_flag = False
 eesti_flag = False
@@ -71,7 +72,8 @@ or (int(month) == 1 and int(day) <= 5):
 elif (int(month) == 2 and int(day) == 24) \
 or (int(month) == 8 and int(day) == 20):
     eesti_flag = True
-elif (int(month) == 4 and int(day) == 23):
+elif (int(month) == 4 and int(day) == 23) \
+or (int(month) == 11 and int(day) == 14):
     anglo_flag = True
 
 language_setup_list = [
@@ -250,7 +252,7 @@ language_setup_list = [
     'Tigrinya', 'ti',
     'Tonga', 'to',
     'Tsonga', 'ts',
-    'Turkish', 'tr',
+    _('Turkish'), 'tr',
     'Turkmen', 'tk',
     'Twi', 'tw',
     'Uyghur', 'ug',
@@ -879,8 +881,12 @@ TOOLBAR_ICON_DICT = {
     'tool_folder_small': 'folder_small.png',
     'tool_hide_large': 'hide_large.png',
     'tool_hide_small': 'hide_small.png',
+    'tool_options_large': 'options_large.png',
+    'tool_options_small': 'options_small.png',
     'tool_playlist_large': 'playlist_large.png',
     'tool_playlist_small': 'playlist_small.png',
+    'tool_preferences_large': 'preferences_large.png',
+    'tool_preferences_small': 'preferences_small.png',
     'tool_quit_large': 'quit_large.png',
     'tool_quit_small': 'quit_small.png',
     'tool_stop_large': 'stop_large.png',
@@ -904,6 +910,8 @@ LARGE_ICON_DICT = {
     'folder_temp_large': 'folder_blue.png',
     'hand_left_large': 'hand_left.png',
     'hand_right_large': 'hand_right.png',
+    'learn_left_large': 'learn_left.png',
+    'learn_right_large': 'learn_right.png',
     'limits_off_large': 'limits_off.png',
     'limits_on_large': 'limits_on.png',
     'playlist_large': 'playlist.png',
@@ -1032,6 +1040,8 @@ STOCK_ICON_DICT = {
     'stock_redo': 'resort_small.png',           # Used for a sorting button
     'stock_refresh': 'refresh_small.png',
     'stock_show_filter': 'show_filter_small.png',
+    'stock_sort_ascending': 'sort_ascending_small.png',
+    'stock_sort_descending': 'sort_descending_small.png',
 }
 
 if xmas_flag:
@@ -1205,7 +1215,7 @@ def do_translate(config_flag=False):
 
         # File output templates use a combination of English words, each of
         #   which must be translated
-        translate_note = _(
+        ignore_me = _(
             'TRANSLATOR\'S NOTE: ID refers to a video\'s unique ID on the' \
             + ' website, e.g. on YouTube "CS9OO0S5w2k"',
         )
