@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2022 A S Lewis
+# Copyright (C) 2019-2023 A S Lewis
 #
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
 #
 # This program is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 # details.
 #
-# You should have received a copy of the GNU General Public License along with
-# this program. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 
 """Module that contains a class storing download options."""
@@ -54,6 +54,20 @@ class OptionsManager(object):
     Tartube's options.OptionsManager implements a subset of options implemented
     by the equivalent class in youtube-dl-gui.
 
+    Args:
+
+        uid (int): Unique ID for this options manager
+
+        name (str): A non-unique name for this options manager. Options
+            managers that, on creation, are attached to a particular media data
+            object have the same name as that object
+
+        dbid (int or None): If this options manager, on create, is attached to
+            a particular media data object, the .dbid of that object; otherwise
+            None
+
+    Canonical list of options:
+
     Options are listed here in the same order in which they appear in
     youtube-dl's documentation.
 
@@ -155,6 +169,9 @@ class OptionsManager(object):
 
         retries (int): Number of youtube-dl retries
 
+        abort_on_unavailable_fragment (bool): Abort download if a fragment is
+            unavailable (default is to skip unavailable fragments)
+
         playlist_reverse (bool): When True, download playlist videos in reverse
             order
 
@@ -304,8 +321,9 @@ class OptionsManager(object):
             values are 'mp3', 'wav', 'aac', 'm4a', 'vorbis', 'opus' & 'flac'
 
         audio_quality (str): Audio quality of the post-processed file.
-            Available values are '9', '5', '0'. The lowest the value the better
-            the quality
+            Available values for VBR are '9' ('high'), '5' (medium) or '0'
+            ('low'). Other values are '320k', '256k', '192k', '128k', '96k'.
+            The default value is 5
 
         recode_video (str): Encode the video to another format if necessary.
             One of the strings 'avi', 'flv', 'mkv', 'mp4', 'ogg', 'webm', or an
@@ -403,7 +421,7 @@ class OptionsManager(object):
             the name/path of the profile to load cookies from; a string in the
             from BROWSER[+KEYRING][:PROFILE]
 
-        no_cookies_from_browser (bool): If true, does not load cookies from the
+        no_cookies_from_browser (bool): If True, does not load cookies from the
             browser (default)
 
         [Internet Shortcut Options]
@@ -559,11 +577,11 @@ class OptionsManager(object):
             the 'Check all' button), the video's JSON file is always loaded
             into memory
 
-            If 'write_description' and 'sim_keep_description' are both true,
+            If 'write_description' and 'sim_keep_description' are both True,
             the description file is written directly to the sub-directory in
             which Tartube would store the video
 
-            If 'write_description' is true but 'sim_keep_description' not, the
+            If 'write_description' is True but 'sim_keep_description' not, the
             description file is written to the equivalent location in Tartube's
             temporary directories.
 
@@ -572,8 +590,11 @@ class OptionsManager(object):
         use_fixed_folder (str or None): If not None, then all videos are
             downloaded to one of Tartube's fixed folders (not including private
             folders) - currently, that group consists of only 'Temporary
-            Videos' and 'Unsorted Videos'. The value should match the name of
-            the folder
+            Videos', 'Unsorted Videos' and 'Video Clips' (or their translated
+            equivalents). The value, if not None, should be 'temp' (matches
+            mainapp.TartubeApp.fixed_temp_folder), 'misc'
+            (matches mainapp.TartubeApp.fixed_misc_folder) or 'clips'
+            (matches mainapp.TartubeApp.fixed_clips_folder)
 
         match_title_list (list): Download only matching titles (regex or
             caseless sub-string). Each item in the list is passed to youtube-dl
@@ -601,7 +622,7 @@ class OptionsManager(object):
         subs_lang_list (list): List of language tags which are used to set
             the 'subs_lang' option
 
-        downloader_config (bool): If true, a youtube-dl configuration is
+        downloader_config (bool): If True, a youtube-dl configuration is
             specified with the '--config-location' option. On Linux/MacOS, the
             user-wide configuration file is used
             ('~/.config/youtube-dl/config'). On MS Windows, a file in the
@@ -629,9 +650,12 @@ class OptionsManager(object):
         # A short description, intended for use in the Drag and Drop tab
         # Empty strings are valid as descriptions
         self.descrip = name
-        # If this object is attached to a media data object, the .dbid of that
-        #   object; otherwise None
-        self.dbid = dbid
+        # A list of .dbid value for any media data objects to which this
+        #   options manager is attached. (When attached to a media.Folder,
+        #   this options manager applies to any child video, channel, playlist
+        #   or sub-folder)
+        # An empty list if not attached to a media data object
+        self.dbid_list = []
 
         # Dictionary of download options for youtube-dl, set by a call to
         #   self.reset_options
@@ -641,6 +665,9 @@ class OptionsManager(object):
         # Code
         # ----
 
+        if dbid is not None:
+            self.dbid_list = [dbid]
+
         # Initialise youtube-dl options
         self.reset_options()
 
@@ -757,6 +784,7 @@ class OptionsManager(object):
             # DOWNLOAD OPTIONS
             'limit_rate': '',             # Can't be directly modified by user
             'retries': 10,
+            'abort_on_unavailable_fragment': False,
             'playlist_reverse': False,
             'playlist_random': False,
             'native_hls': True,
@@ -966,14 +994,22 @@ class OptionsManager(object):
     # Set accessors
 
 
-    def set_dbid(self, dbid):
+    def add_dbid(self, dbid):
 
-        self.dbid = dbid
+        # (Don't add duplicates. This might be a concern, when called from
+        #   mainapp.TartubeApp.fix_integrity_db() )
+        if not dbid in self.dbid_list:
+            self.dbid_list.append(dbid)
+
+
+    def del_dbid(self, dbid):
+
+        self.dbid_list.remove(dbid)
 
 
     def reset_dbid(self):
 
-        self.dbid = None
+        self.dbid_list = []
 
 
 class OptionsParser(object):
@@ -1078,6 +1114,12 @@ class OptionsParser(object):
             OptionHolder('limit_rate', '-r', ''),
             # -R, --retries RETRIES
             OptionHolder('retries', '-R', 10),
+            # --abort-on-unavailable-fragment
+            OptionHolder(
+                'abort_on_unavailable_fragment',
+                '--abort-on-unavailable-fragment',
+                False
+            ),
             # --playlist-reverse
             OptionHolder('playlist_reverse', '--playlist-reverse', False),
             # --playlist-random
@@ -1387,7 +1429,7 @@ class OptionsParser(object):
                 involved, the corresponding object (so bandwidth limits can be
                 extracted)
 
-        Returns:
+        Return values:
 
             List of strings with all the youtube-dl command line options
 
@@ -1483,7 +1525,7 @@ class OptionsParser(object):
                 cookies_path = copy_dict[option_holder_obj.name]
                 options_list.append('--cookies')
                 # If no path is specified, use a standard location for the
-                #   cookie jar (otherwise youtube-dl(c) will write it to
+                #   cookie jar (otherwise youtube-dl will write it to
                 #   ../tartube/tartube)
                 if cookies_path == '':
                     options_list.append(
@@ -1709,7 +1751,11 @@ class OptionsParser(object):
 
         """
 
-        override_name = copy_dict['use_fixed_folder']
+        # Fetch the equivalent fixed folder 'Temporary Videos', 'Unsorted
+        #   Videos' or 'Video Clips', if specified
+        override_obj = self.app_obj.get_fixed_folder(
+            copy_dict['use_fixed_folder']
+        )
 
         if operation_type == 'classic_sim' \
         or operation_type == 'classic_real' \
@@ -1720,13 +1766,10 @@ class OptionsParser(object):
             dir_path = media_data_obj.dummy_dir
 
         elif not isinstance(media_data_obj, media.Video) \
-        and override_name is not None \
-        and override_name in self.app_obj.media_name_dict:
+        and override_obj is not None:
 
             # Because of the override, save all videos to a system folder
-            other_dbid = self.app_obj.media_name_dict[override_name]
-            other_obj = self.app_obj.media_reg_dict[other_dbid]
-            dir_path = other_obj.get_default_dir(self.app_obj)
+            override_obj = other_obj.get_default_dir(self.app_obj)
 
         elif isinstance(media_data_obj, media.Video):
             dir_path = media_data_obj.parent_obj.get_actual_dir(self.app_obj)
@@ -1857,7 +1900,10 @@ class OptionsParser(object):
                     # v2.1.009: Since the user doesn't have the possibility of
                     #   setting the -f and --merge-output-format options to the
                     #   same value (e.g. 'mp4'), we must do so artificially
-                    copy_dict['merge_output_format'] = this_format
+                    # yt-dlp supports: avi, flv, mkv, mov, mp4, webm
+                    if this_format in formats.VIDEO_FORMAT_DICT \
+                    and this_format != 'ogg':
+                        copy_dict['merge_output_format'] = this_format
 
                     return
 
@@ -2062,7 +2108,7 @@ class OptionHolder(object):
 
             copy_dict (dict): Copy of the original options dictionary.
 
-        Returns:
+        Return values:
 
             True if any of the required options is enabled, otherwise returns
                 False.
@@ -2079,7 +2125,7 @@ class OptionHolder(object):
 
         """Called by options.OptionsParser.parse().
 
-        Returns:
+        Return values:
 
             True if the option is a boolean switch, otherwise returns False
 
