@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2022 A S Lewis
+# Copyright (C) 2019-2023 A S Lewis
 #
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
 #
 # This program is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 # details.
 #
-# You should have received a copy of the GNU General Public License along with
-# this program. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 
 """Update operation classes."""
@@ -166,12 +166,21 @@ class UpdateManager(threading.Thread):
         Executes the system command, creating a new child process which
         executes youtube-dl.
 
+        Updates self.stderr_list in the event of an error.
+
         Args:
 
             cmd_list (list): Python list that contains the command to execute
 
         """
 
+        # Strip double quotes from arguments
+        # (Since we're sending the system command one argument at a time, we
+        #   don't need to retain the double quotes around any single argument
+        #   and, in fact, doing so would cause an error)
+        cmd_list = utils.strip_double_quotes(cmd_list)
+
+        # Create the child process
         info = preexec = None
 
         if os.name == 'nt':
@@ -750,7 +759,7 @@ class UpdateManager(threading.Thread):
         Called continuously during the self.run() loop to check whether the
         child process has finished or not.
 
-        Returns:
+        Return values:
 
             True if the child process is alive, otherwise returns False.
 
